\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{acord}[2022/07/09 Format estàndard per acords d'òrgans UPC]

%% Les opcions de la classe
\RequirePackage{kvoptions}
\RequirePackage{ifthen}

% Formatat a dues columnes
\DeclareBoolOption[false]{twocolumn}

% Logo EPSEM en comptes del normatiu UPC
\DeclareBoolOption[true]{upc}
\DeclareComplementaryOption{epsem}{upc}

% Quan el contingut te altra forma: legal, article, report
\DeclareStringOption[legal]{content}

% Nomes pel format legal, com encapçalar els articles. art, segno
\DeclareStringOption[art]{artformat}

% Nomes pel legal, si es vol color als apartats: none, sect, art, par
\DeclareStringOption[none]{color}

% Nomes pel legal, numeració paràgrafs: none, margin, inside
\DeclareStringOption[margin]{parnum}

\ProcessKeyvalOptions*\relax

%% Processa el format del num article
\newif\ifacord@withart
\ifthenelse{\equal{\acord@artformat}{art}}{
  \acord@witharttrue
}{
  \ifthenelse{\equal{\acord@artformat}{segno}}{
    \acord@withartfalse
  }{
    \ClassError{control}{Wrong 'artformat' option value}{Use:
      art, segno}
  }
}

%% Processa el format del contingut
\newif\ifacord@article
\newif\ifacord@legal
\ifthenelse{\equal{\acord@content}{legal}}{
  \acord@articletrue\acord@legaltrue
}{
  \ifthenelse{\equal{\acord@content}{article}}{
    \acord@articletrue\acord@legalfalse
  }{
    \ifthenelse{\equal{\acord@content}{report}}{
      \acord@articlefalse\acord@legalfalse
    }{
      \ClassError{control}{Wrong 'content' option value}{Use:
        legal, article, report}
    }
  }
}

%% Processa l'acoloriment dels apartats
\newif\ifacord@colorpar\acord@colorparfalse
\ifthenelse{\equal{\acord@color}{none}}{
  \def\acord@seccol{} \def\acord@artcol{}
}{
  \ifthenelse{\equal{\acord@color}{sec}}{
    % seccions upc
    \def\acord@seccol{\color{upcblue}} \def\acord@artcol{}
  }{
    \ifthenelse{\equal{\acord@color}{art}}{
      % articles i seccions upc
      \def\acord@seccol{\color{upcblue}} \def\acord@artcol{\color{upcblue}}
    }{
      \ifthenelse{\equal{\acord@color}{par}}{
        \def\acord@seccol{\color{upcblue}}
        \def\acord@artcol{\color{upcblue}}
        \acord@colorpartrue
      }{
        \ClassError{control}{Wrong 'color' option value}{Use:
          none, dec, art}
      }
    }
  }
}


%% Processa la numeració dels paràgrafs
\newif\ifacord@numinside
\newif\ifacord@nummargin
\ifthenelse{\equal{\acord@parnum}{none}}{
  \acord@numinsidefalse \acord@nummarginfalse
}{
  \ifthenelse{\equal{\acord@parnum}{margin}}{
    \acord@numinsidefalse \acord@nummargintrue
  }{
    \ifthenelse{\equal{\acord@parnum}{inside}}{
      \acord@numinsidetrue \acord@nummarginfalse
    }{
      \ClassError{control}{Wrong 'parnum' option value}{Use:
        none, margin, inside}
    }
  }
}



\ifacord@article
\LoadClass[parskip=half,titlepage=yes,twoside=semi,]{scrartcl}
\else
\LoadClass[parskip=half,titlepage=yes,twoside=semi,]{scrreprt}
\fi

%% Lletra, llengua i codificació
\RequirePackage[T1]{fontenc}
\RequirePackage[main=catalan,shorthands=off]{babel}
\RequirePackage[scale=0.9]{tgheros}
\renewcommand{\familydefault}{\sfdefault}
%\renewcommand{\ttdefault}{\sfdefault}
\RequirePackage[italic]{mathastext}




%% Canvis generals si a 2 cols/legal
\ifacord@twocolumn
  \KOMAoptions{fontsize=10pt, twocolumn=yes, DIV=15}
  \setlength{\columnsep}{2.5em}
  \RequirePackage{flushend}
\else
  \KOMAoptions{fontsize=11pt}
\fi
\ifacord@legal
  \KOMAoptions{headings=small}
\fi

%% La caràtula principal dels acords

% Paquets per la caràtula
\RequirePackage{bolaupc,xcolor,typearea}
\RequirePackage{tcolorbox}
\tcbuselibrary{skins}

% Entorn per enregistrar la història de l'acord
\RequirePackage{environ}
\def\acord@history{}
\NewEnviron{history}{\xdef\acord@history{\unexpanded\expandafter{\BODY}}}

% Colors normatius
\definecolor{grisa}{HTML}{D9D9D9}
\definecolor{grisz}{HTML}{F2F2F2}
\definecolor{blauet}{HTML}{AFE2FB}
\definecolor{blauot}{HTML}{00B0F0}

% La portada amb caràtula a doble cara
\renewcommand{\maketitle}{
  % fixa una typearea concreta i independent per a la portada
  \storeareas\StandardArea
  \areaset{13cm}{23cm}
  \addtolength{\topmargin}{8mm}
  \begin{titlepage}
    \centering
    \begin{tcolorbox}[enhanced,fontlower=\bfseries\huge, halign
      upper=left, halign lower=flush left, valign lower=center, width=13cm,
      sharp corners, height=11cm, interior style={top color=grisa,
        bottom color=grisz}, boxrule=0pt, lower separated=false]
      \ifacord@upc\logoupc[15mm]\else\logoepsem[15mm]\fi
      \tcblower
      \@title
    \end{tcolorbox}
    \begin{tcolorbox}[colback=blauet, fontupper=\bfseries\Large,
      halign=flush left, valign=center, width=13cm, sharp corners, height=3cm,
      boxrule=0pt]
      \@subtitle
    \end{tcolorbox}
    \begin{tcolorbox}[colback=blauot, colupper=white,
      fontupper=\bfseries\large,
      halign=center, width=13cm, sharp corners, height=1.4cm,
      boxrule=0pt, valign=center]
      \@author
    \end{tcolorbox}
    \bigskip
    \begin{minipage}{13cm}
      \large
      \ifx\acord@history\empty\else
      \begin{itemize}
        \acord@history
      \end{itemize}
      \fi
    \end{minipage}
    \cleardoubleoddemptypage{}
  \end{titlepage}
  % canvia cos després de fer portada si a dues columnes
  \ifacord@twocolumn\KOMAoptions{fontsize=10pt}\fi
  % recupera typearea original
  \StandardArea
  \setcounter{page}{1}
}

\AtBeginDocument{%
  %  nasty trick to avoid:
  %  https://www.mail-archive.com/tex-hyphen@tug.org/msg01801.html
  \lccode`'=0
  \maketitle{}
}

%% Configuració d'aspectes generals

% Etiquetat de les enumeracions específic per acords
\renewcommand{\labelenumi}{\alph{enumi})}
\renewcommand{\labelenumii}{\roman{enumii})}
\renewcommand{\labelenumiii}{\arabic{enumiii})}


%%
%% Configuració dels entorns per contingut legal
%%
\ifacord@legal

% Aspecte de les seccions (capítols legislatius)
\setkomafont{section}{\acord@seccol\centering\Large\normalfont\scshape}
\setcounter{secnumdepth}{-10}
\RedeclareSectionCommands[
  beforeskip=-.5\baselineskip,
  afterskip=.1\baselineskip,
]{section,subsection,subsubsection}

% Load package jura
\RequirePackage[
juratotoc=2,
]{scrjura}

% Ajusta mida index segons configuracio
\ifacord@withart
  \ifacord@twocolumn
    \KOMAoption{juratocnumberwidth}{3.6em}
  \else
    \KOMAoption{juratocnumberwidth}{5em}
  \fi
\else
  \KOMAoption{juratocnumberwidth}{2.5em}
\fi

\addtokomafont{contract.Clause}{\raggedright\acord@artcol}

% Aspecte del numero de paràgraf
\ifacord@nummargin
  \ifacord@colorpar
    \setkomafont{parnumber}{\footnotesize\textcolor{upcblue}}
  \else
    \setkomafont{parnumber}{\footnotesize\textcolor{black!50}}
  \fi
  \renewcommand{\parformat}{\makebox[0pt][r]{\thepar\;}}
  \renewcommand{\parformatseparation}{}
\else
  \ifacord@numinside
    \ifacord@colorpar
      \setkomafont{parnumber}{\normalsize\textcolor{upcblue}}
    \else
      \setkomafont{parnumber}{\normalsize}
    \fi
    \renewcommand{\parformat}{\thepar{.}}
    \renewcommand{\parformatseparation}{\;}
  \else
    \renewcommand{\parformat}{}
    \renewcommand{\parformatseparation}{}
  \fi
\fi


% Definició de l'article
\ifacord@twocolumn
\newcommand{\article}[1]{%
  \Clause{title={#1},preskip=0.2\baselineskip,postskip=0pt}}
\else
\newcommand{\article}[1]{%
  \Clause{title={#1},preskip=0.4\baselineskip,postskip=0.2\baselineskip}}
\fi

% Definició del capítol legislatiu
\newenvironment{provisions}{\begin{contract}}{\end{contract}}
\newcommand{\artsection}[1]{\end{contract}\addsec{#1}\begin{contract}}

% Localització de les referències
\providecaptionname{catalan}{\parname}{paràgraf}
\providecaptionname{catalan}{\parshortname}{par.}

% Configura referència estàndard
\KOMAoption{ref}{numeric,sentenceoff}
\ifacord@withart
  \ifacord@twocolumn
    \renewcommand*{\Clauseformat}[1]{Art.\,#1}
    \renewcommand*{\parnumericformat}[1]{\unskip{.}#1}
  \else
    \renewcommand*{\Clauseformat}[1]{Article\,#1}
    \renewcommand*{\parnumericformat}[1]{\unskip{.}#1}
  \fi
\else
  \renewcommand*{\Clauseformat}[1]{\S#1}
  \renewcommand*{\parnumericformat}[1]{\unskip{.}#1}
\fi

\fi


%% Enllaços interns (ha de carregar després de jura)
\RequirePackage[hidelinks]{hyperref}
